Assertables: Rust crate of assert macros for testing
The assertables Rust crate provides many assert macros to improve your
compile-time tests and run-time reliability.
- Crate: https://crates.io/crates/assertables
- Docs: https://docs.rs/assertables/
- Repo: https://github.com/sixarm/assertables-rust-crate/
- Contact: joel@joelparkerhenderson.com
Introduction
The Rust programming language provides a few built-in assert macros to test code:
The Rust programming language provides assert macros to test code:
assert!(a)// a is trueassert_eq!(a, b)// a is equal to bassert_ne!(a, b)// a is not equal to b
The assertables crate provides many more, to help you work with numbers, strings, results, options, iterators, files, commands, and more. See below for the macros.
Top benefits:
- You can write better tests to improve reliability and maintainability.
- You can handle more corner cases without needing to write custom code.
- You can troubleshoot faster because error messages show specifics.
Top features:
- Easy to use: everything is well-documented with runnable examples.
- Runtime savvy: all the assertables macros have runtime versions.
- Zero overhead: if you don’t use a macro, then it’s never compiled.
To use the macros, add this to your Cargo.toml file:
[dev-dependencies]
assertables = "*"Highlights
For values:
assert_lt!(a, b)// less thanassert_le!(a, b)// less than or equal toassert_gt!(a, b)// greater thanassert_ge!(a, b)// greater than or equal to
For approximations:
For groups:
For strings:
For lengths:
For matching:
For infix operators:
For nearness:
For Result Ok/Err:
For Option Some/None:
For Poll Ready/Pending:
For comparing collections that provide into_iter() such as arrays and
vectors:
assert_set_eq!(collection1, collection2)assert_bag_eq!(collection1, collection2)assert_iter_eq!(collection1, collection2)
For file system paths and input/output readers:
For command capture of standard output and standard error:
assert_command_stdout_eq!(command1, command2)assert_program_args_stdout_eq!(program1, args1, program2, args2);
Modules
There are many more macros that are organized in modules.
Modules for values:
Modules for strings:
Modules for lengths:
Modules for matching:
Modules for collections, such as arrays, vectors, lists, maps:
assert_iterfor iterator collections.assert_setfor set collections.assert_bagfor bag collections.
Modules for Result Ok/Err:
Modules for Option Some/None:
Modules for Poll Ready/Pending:
Modules for functions:
assert_fnfor functions in general.assert_fn_okfor functions that return Result::Ok.assert_fn_errfor functions that return Result::Err.
Modules for readers:
assert_fs_read_to_stringfor file system path contents.assert_io_read_to_stringfor input/output reader streams.
Modules for external calls:
assert_commandfor commands and their stdout & stderr.assert_program_argsfor programs with args and their stdout & stderr.
Forms
All assertables macros have forms for an optional message:
assert_gt!(a, b)// automatic messageassert_gt!(a, b, "Your text")// custom message
All assertables macros have forms for different outcomes:
assert_gt!(a, b)// panic during typical testassert_gt_as_result!(a, b)// return Ok or Errdebug_assert_gt!(a, b)// panic when in debug mode
Many assertables macros have forms for comparing left hand side (LHS) and right hand side (RHS) as the same type or as an arbitrary expression:
assert_ok_eq!(a, b)// Ok(…) = Ok(…)assert_ok_eq_expr!(a, b)// Ok(…) = expression
Tracking
-
Package: assertables-rust-crate
-
Version: 8.16.0
-
Created: 2021-03-30T15:47:49Z
-
Updated: 2024-10-08T15:07:34Z
-
License: MIT or Apache-2.0 or GPL-2.0 or GPL-3.0 or contact us for more
-
Contact: Joel Parker Henderson (joel@sixarm.com)
Modules
- Assert a condition is true.
- Assert every element of the iterator matches a predicate.
- Assert every element of the iterator matches a predicate.
- Assert macros for comparing bag collections.
- Assert macros for comparing commands and their stdout & stderr.
- Assert an expression is equal to another expression.
- Assert macros for Err(_) items.
- Assert macros for comparing functions.
- Assert macros for comparing functions that return errors.
- Assert macros for comparing functions that return Result::Ok.
- Assert macros for comparing file system path contents.
- Assert an expression is greater than or equal to another expression.
- Assert an expression is greater than another expression.
- Assert a number is within delta of another number.
- Assert a number is within epsilon of another number.
- Assert a infix operator, such as assert_infix!(a == b).
- Assert macros for comparing input/output reader streams.
- Assert macros for comparing iter collections.
- Assert an expression is less than or equal to another expression.
- Assert macros for comparing lengths.
- Assert an expression is less than another expression.
- Assert an expression is not equal to another expression.
- Assert macro for None items.
- Assert macros for Ok(_) items.
- Assert macros for
Option{Some,None} - Assert macro for Pending items.
- Assert macros for
Poll{Ready,Pending} - Assert macros for comparing programs with arguments.
- Assert macros for Ready(_) items.
- Assert macros for
Result{Ok,Err} - Assert macros for comparing set collections.
- Assert macros for Some(_) items.
Macros
- Assert every element of the iterator matches a predicate.
- Assert every element of the iterator matches a predicate.
- Assert every element of the iterator matches a predicate.
- Assert every element of the iterator matches a predicate.
- Assert a number is approximately equal to another number.
- Assert a number is approximately equal to another number.
- Assert a number is approximately not equal to another number.
- Assert a number is approximately not equal to another number.
- Assert a condition is true.
- Assert a bag is equal to another.
- Assert a bag is equal to another.
- Assert a bag is not equal to another.
- Assert a bag is not equal to another.
- Assert a bag is a subbag of another.
- Assert a bag is a subbag of another.
- Assert a bag is a superbag of another.
- Assert a bag is a superbag of another.
- assert_
command_ stderr_ contains Deprecated Assert a command stderr string contains a given containee. - assert_
command_ stderr_ contains_ as_ result Deprecated Assert a command stderr string contains a given containee. - Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to an expression.
- assert_
command_ stderr_ is_ match Deprecated Assert a command stderr string is a match to a regex. - assert_
command_ stderr_ is_ match_ as_ result Deprecated Assert a command stderr string is a match to a regex. - Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string contains a given containee.
- Assert a command stderr string contains a given containee.
- Assert a command stderr string is a match to a regex.
- Assert a command stderr string is a match to a regex.
- assert_
command_ stdout_ contains Deprecated Assert a command stdout string contains a given containee. - assert_
command_ stdout_ contains_ as_ result Deprecated Assert a command stdout string contains a given containee. - Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to an expression.
- assert_
command_ stdout_ is_ match Deprecated Assert a command stdout string is a match to a regex. - assert_
command_ stdout_ is_ match_ as_ result Deprecated Assert a command stdout string is a match to a regex. - Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string contains a given containee.
- Assert a command stdout string contains a given containee.
- Assert a command stdout string is a match to a regex.
- Assert a command stdout string is a match to a regex.
- Assert a container is a match for an expression.
- Assert an expression (such as a string) contains an expression (such as a substring).
- Assert an expression (such as a string) ends with an expression (such as a string).
- Assert an expression (such as a string) ends with an expression (such as a substring).
- Assert an expression is equal to another expression.
- Assert expression is Err(_).
- Assert expression is Err(_).
- Assert two expressions are Err(_) and their values are equal.
- Assert two expressions are Err(_) and their values are equal.
- Assert an expression is Err(_) and its value is equal to an expression.
- Assert an expression is Err(_) and its value is equal to an expression.
- Assert two expressions are Err(_) and their values are not equal.
- Assert two expressions are Err(_) and their values are not equal.
- Assert an expression is Err(_) and its value is equal to an expression.
- Assert an expression is Err(_) and its value is equal to an expression.
- Assert a function output is equal to another function output.
- Assert a function output is equal to another function output.
- Assert a function output is equal to an expression.
- Assert a function output is equal to an expression.
- Assert a function error is equal to another.
- Assert a function error is equal to another.
- Assert a function error is equal to an expression.
- Assert a function error is equal to an expression.
- Assert a function error is greater than or equal to another.
- Assert a function error is greater than or equal to another.
- Assert a function error is greater than or equal to an expression.
- Assert a function error is greater than or equal to an expression.
- Assert a function error is greater than another.
- Assert a function error is greater than another.
- Assert a function error is greater than an expression.
- Assert a function error is greater than an expression.
- Assert a function error is less than or equal to another.
- Assert a function error is less than or equal to another.
- Assert a function error is less than or equal to an expression.
- Assert a function error is less than or equal to an expression.
- Assert a function error is less than another.
- Assert a function error is less than another.
- Assert a function error is less than an expression.
- Assert a function error is less than an expression.
- Assert a function error is not equal to another.
- Assert a function error is not equal to another.
- Assert a function error is not equal to an expression.
- Assert a function error is not equal to an expression.
- Assert a function output is greater than or equal to another.
- Assert a function output is greater than or equal to another.
- Assert a function output is greater than or equal to an expression.
- Assert a function output is greater than or equal to an expression.
- Assert a function output is greater than another.
- Assert a function output is greater than another.
- Assert a function output is greater than an expression.
- Assert a function output is greater than an expression.
- Assert a function output is less than or equal to another.
- Assert a function output is less than or equal to another.
- Assert a function output is less than or equal to an expression.
- Assert a function output is less than or equal to an expression.
- Assert a function output is less than another.
- Assert a function output is less than another.
- Assert a function output is less than an expression.
- Assert a function output is less than an expression.
- Assert a function output is not equal to another.
- Assert a function output is not equal to another.
- Assert a function output is not equal to an expression.
- Assert a function output is not equal to an expression.
- Assert a function Ok(…) is equal to another.
- Assert a function Ok(…) is equal to another.
- Assert a function Ok(…) is equal to an expression.
- Assert a function Ok(…) is equal to an expression.
- Assert a function Ok(…) is greater than or equal to another.
- Assert a function Ok(…) is greater than or equal to another.
- Assert a function Ok(…) is greater than or equal to an expression.
- Assert a function Ok(…) is greater than or equal to an expression.
- Assert a function Ok(…) is greater than another.
- Assert a function Ok(…) is greater than another.
- Assert a function Ok(…) is greater than an expression.
- Assert a function Ok(…) is greater than an expression.
- Assert a function Ok(…) is less than or equal to another.
- Assert a function Ok(…) is less than or equal to another.
- Assert a function Ok(…) is less than or equal to an expression.
- Assert a function Ok(…) is less than or equal to an expression.
- Assert a function Ok(…) is less than another.
- Assert a function Ok(…) is less than another.
- Assert a function Ok(…) is less than an expression.
- Assert a function Ok(…) is less than an expression.
- Assert a function Ok(…) is not equal to another.
- Assert a function Ok(…) is not equal to another.
- Assert a function Ok(…) is not equal to an expression.
- Assert a function Ok(…) is not equal to an expression.
- Assert a std::fs::read_to_string(path) contains a pattern.
- Assert a std::fs::read_to_string(path) contains a pattern.
- Assert a std::fs::read_to_string(path) value is equal to another.
- Assert a std::fs::read_to_string(path) is equal to another.
- Assert a std::fs::read_to_string(path) value is equal to an expression.
- Assert a std::fs::read_to_string(path) value is equal to an expression.
- Assert a std::fs::read_to_string(path) value is greater than or equal to another.
- Assert a std::fs::read_to_string(path) value is greater than or equal to another.
- Assert a std::fs::read_to_string(path) value is greater than or equal to an expression.
- Assert a std::fs::read_to_string(path) value is greater than or equal to an expression.
- Assert a std::fs::read_to_string(path) value is greater than another.
- Assert a std::fs::read_to_string(path) value is greater than another.
- Assert a std::fs::read_to_string(path) value is greater than an expression.
- Assert a std::fs::read_to_string(path) value is greater than an expression.
- Assert a std::fs::read_to_string(path) value is less than or equal to another.
- Assert a std::fs::read_to_string(path) value is less than or equal to another.
- Assert a std::fs::read_to_string(path) value is less than or equal to an expression.
- Assert a std::fs::read_to_string(path) value is less than or equal to an expression.
- Assert a std::fs::read_to_string(path) value is less than another.
- Assert a std::fs::read_to_string(path) value is less than another.
- Assert a std::fs::read_to_string(path) value is less than an expression.
- Assert a std::fs::read_to_string(path) value is less than an expression.
- Assert a std::fs::read_to_string(path) is a match to a regex.
- Assert a std::fs::read_to_string(path) is a match to a regex.
- Assert a std::fs::read_to_string(path) is not equal to another.
- Assert a std::fs::read_to_string(path) is not equal to another.
- Assert a std::fs::read_to_string(path) is not equal to an expression.
- Assert a std::fs::read_to_string(path) is not equal to an expression.
- Assert an expression is greater than or equal to another expression.
- Assert an expression is greater than or equal to another expression.
- Assert an expression is greater than another expression.
- Assert an expression is greater than another expression.
- Assert a number is within delta of another number.
- Assert a number is within delta of another number.
- Assert a number is within epsilon of another number.
- Assert a number is within epsilon of another number.
- Assert a infix operator, such as assert_infix!(a == b).
- Assert a infix operator, such as assert_infix!(a == b).
- Assert a std::io::Read read_to_string() contains a pattern.
- Assert a std::io::Read read_to_string() contains a pattern.
- Assert a std::io::Read read_to_string() value is equal to another.
- Assert a std::io::Read read_to_string() is equal to another.
- Assert a std::io::Read read_to_string() value is equal to an expression.
- Assert a std::io::Read read_to_string() value is equal to an expression.
- Assert a std::io::Read read_to_string() value is greater than or equal to another.
- Assert a std::io::Read read_to_string() value is greater than or equal to another.
- Assert a std::io::Read read_to_string() value is greater than or equal to an expression.
- Assert a std::io::Read read_to_string() value is greater than or equal to an expression.
- Assert a std::io::Read read_to_string() value is greater than another.
- Assert a std::io::Read read_to_string() value is greater than another.
- Assert a std::io::Read read_to_string() value is greater than an expression.
- Assert a std::io::Read read_to_string() value is greater than an expression.
- Assert a std::io::Read read_to_string() value is less than or equal to another.
- Assert a std::io::Read read_to_string() value is less than or equal to another.
- Assert a std::io::Read read_to_string() value is less than or equal to an expression.
- Assert a std::io::Read read_to_string() value is less than or equal to an expression.
- Assert a std::io::Read read_to_string() value is less than another.
- Assert a std::io::Read read_to_string() value is less than another.
- Assert a std::io::Read read_to_string() value is less than an expression.
- Assert a std::io::Read read_to_string() value is less than an expression.
- Assert a std::io::Read read_to_string() is a match to a regex.
- Assert a std::io::Read read_to_string() is a match to a regex.
- Assert a std::io::Read read_to_string() is not equal to another.
- Assert a std::io::Read read_to_string() is not equal to another.
- Assert a std::io::Read read_to_string() is not equal to an expression.
- Assert a std::io::Read read_to_string() is not equal to an expression.
- Assert an expression (such as a string or array) is empty.
- Assert an expression (such as a regex) is a match for an expression (such as a string).
- Assert a matcher is a match for an expression.
- Assert an expression (such as a regex) is a match for an expression (such as a string).
- Assert an iterable is equal to another.
- Assert an iterable is equal to another.
- Assert an iterable is greater than or equal to another.
- Assert an iterable is greater than or equal to another.
- Assert an iterable is greater than another.
- Assert an iterable is greater than another.
- Assert an iterable is less than or equal to another.
- Assert an iterable is less than or equal to another.
- Assert an iterable is less than another.
- Assert an iterable is less than another.
- Assert an iterable is not equal to another.
- Assert an iterable is not equal to another.
- Assert an expression is less than or equal to another expression.
- Assert an expression is less than or equal to another expression.
- Assert a length is equal to another length.
- Assert a length is equal to another length.
- Assert a length is equal to an expression.
- Assert a length is equal to an expression.
- Assert a length is greater than or equal to another length.
- Assert a length is greater than or equal to another length.
- Assert a length is greater than or equal to an expression.
- Assert a length is greater than or equal to an expression.
- Assert a length is greater than another length.
- Assert a length is greater than another length.
- Assert a length is greater than an expression.
- Assert a length is greater than an expression.
- Assert a length is less than or equal to another length.
- Assert a length is less than or equal to another length.
- Assert a length is less than or equal to an expression.
- Assert a length is less than or equal to an expression.
- Assert a length is less than another length.
- Assert a length is less than another length.
- Assert a length is less than an expression.
- Assert a length is less than an expression.
- Assert a length is equal to another length.
- Assert a length is equal to another length.
- Assert a length is equal to an expression.
- Assert a length is equal to an expression.
- Assert an expression is less than another expression.
- Assert an expression is less than another expression.
- Assert an expression is not equal to another expression.
- Assert expression is None.
- Assert an expression.is_none() is true.
- Assert an expression (such as a string) does not contain an expression (such as a substring).
- Assert an expression (such as a string) does not contain an expression (such as a substring).
- Assert an expression (such as a string or array) is not empty.
- Assert an expression (such as a string or array) is not empty.
- Assert an expression (such as a string) does not end with an expression (such as a string).
- Assert an expression (such as a string) does not end with an expression (such as a substring).
- Assert an expression (such as a regex) is not a match for an expression (such as a string).
- Assert an expression (such as a regex) is not a match for an expression (such as a string).
- Assert an expression (such as a string) does not start with an expression (such as a string).
- Assert an expression (such as a string) does not start with an expression (such as a substring).
- Assert expression is Ok(_).
- Assert expression is Ok(_).
- Assert two expressions are Ok(_) and their values are equal.
- Assert two expressions are Ok(_) and their values are equal.
- Assert an expression is Ok(_) and its value is equal to an expression.
- Assert an expression is Ok(_) and its value is equal to an expression.
- Assert two expressions are Ok(_) and their values are not equal.
- Assert two expressions are Ok(_) and their values are not equal.
- Assert an expression is Ok(_) and its value is equal to an expression.
- Assert an expression is Ok(_) and its value is equal to an expression.
- assert_
option_ none Deprecated Assert expression is None. - assert_
option_ none_ as_ result Deprecated Assert an expression.is_none() is true. - assert_
option_ some Deprecated Assert expression is Some(_). - assert_
option_ some_ as_ result Deprecated Assert an expression.is_some() is true. - assert_
option_ some_ eq Deprecated Assert two expressions are Some(_) and their values are equal. - assert_
option_ some_ eq_ as_ result Deprecated Assert a.is_some() and a.unwrap() are equal to another. - assert_
option_ some_ ne Deprecated Assert two expressions are Some(_) and their values are not equal. - assert_
option_ some_ ne_ as_ result Deprecated Assert two expressions are Some(_) and their values are not equal. - Assert an expression is Pending.
- Assert an expression.is_pending() is true.
- assert_
poll_ pending Deprecated Assert an expression is Pending. - assert_
poll_ pending_ as_ result Deprecated Assert an expression.is_pending() is true. - assert_
poll_ ready Deprecated Assert an expression is Ready(_). - assert_
poll_ ready_ as_ result Deprecated Assert an expression is Ready(_). - assert_
poll_ ready_ eq Deprecated Assert two expressions are Ready(_) and their values are equal. - assert_
poll_ ready_ eq_ as_ result Deprecated Assert two expressions are Ready(_) and their values are equal. - assert_
poll_ ready_ ne Deprecated Assert two expressions are Ready(_) and their values are not equal. - assert_
poll_ ready_ ne_ as_ result Deprecated Assert two expressions are Ready(_) and their values are not equal. - assert_
program_ args_ stderr_ contains Deprecated Assert a command (built with program and args) stderr string contains a given containee. - Assert a command (built with program and args) stderr string contains a given containee.
- Assert a command (built with program and args) stderr string is equal to another.
- Assert a command (built with program and args) stderr string is equal to another.
- Assert a command (built with program and args) stderr string is equal to an expression.
- Assert a command (built with program and args) stderr string is equal to an expression.
- Assert a command (built with program and args) stderr string is greater than or equal to another.
- Assert a command (built with program and args) stderr string is greater than or equal to another.
- Assert a command (built with program and args) stderr string is greater than or equal to an expression.
- Assert a command (built with program and args) stderr string is greater than or equal to an expression.
- Assert a command (built with program and args) stderr string is greater than to another.
- Assert a command (built with program and args) stderr string is greater than another.
- Assert a command (built with program and args) stderr string is greater than an expression.
- Assert a command (built with program and args) stderr string is greater than an expression.
- assert_
program_ args_ stderr_ is_ match Deprecated Assert a command (built with program and args) stderr string is a match to a regex. - Assert a command (built with program and args) stderr string is a match to a regex.
- Assert a command (built with program and args) stderr string is less than or equal to another.
- Assert a command (built with program and args) stderr string is less than or equal to another.
- Assert a command (built with program and args) stderr string is less than or equal to an expression.
- Assert a command (built with program and args) stderr string is less than or equal to an expression.
- Assert a command (built with program and args) stderr string is less than another.
- Assert a command (built with program and args) stderr string is less than another.
- Assert a command (built with program and args) stderr string is less than an expression.
- Assert a command (built with program and args) stderr string is less than an expression.
- Assert a command (built with program and args) stderr string is not equal to another.
- Assert a command (built with program and args) stderr string is not equal to another.
- Assert a command (built with program and args) stderr string is not equal to an expression.
- Assert a command (built with program and args) stderr string is not equal to an expression.
- Assert a command (built with program and args) stderr string contains a given containee.
- Assert a command (built with program and args) stderr string contains a given containee.
- Assert a command (built with program and args) stderr string is a match to a regex.
- Assert a command (built with program and args) stderr string is a match to a regex.
- assert_
program_ args_ stdout_ contains Deprecated Assert a command (built with program and args) stdout string contains a given containee. - Assert a command (built with program and args) stdout string contains a given containee.
- Assert a command (built with program and args) stdout string is equal to another.
- Assert a command (built with program and args) stdout string is equal to another.
- Assert a command (built with program and args) stdout string is equal to an expression.
- Assert a command (built with program and args) stdout string is equal to an expression.
- Assert a command (built with program and args) stdout string is greater than or equal to another.
- Assert a command (built with program and args) stdout string is greater than or equal to another.
- Assert a command (built with program and args) stdout string is greater than or equal to an expression.
- Assert a command (built with program and args) stdout string is greater than or equal to an expression.
- Assert a command (built with program and args) stdout string is greater than another.
- Assert a command (built with program and args) stdout string is greater than to another.
- Assert a command (built with program and args) stdout string is greater than an expression.
- Assert a command (built with program and args) stdout string is greater than an expression.
- assert_
program_ args_ stdout_ is_ match Deprecated Assert a command (built with program and args) stdout string is a match to a regex. - Assert a command (built with program and args) stdout string is a match to a regex.
- Assert a command (built with program and args) stdout string is less than or equal to another.
- Assert a command (built with program and args) stdout string is less than or equal to another.
- Assert a command (built with program and args) stdout string is less than or equal to an expression.
- Assert a command (built with program and args) stdout string is less than or equal to an expression.
- Assert a command (built with program and args) stdout string is less than another.
- Assert a command (built with program and args) stdout string is less than another.
- Assert a command (built with program and args) stdout string is less than an expression.
- Assert a command (built with program and args) stdout string is less than an expression.
- Assert a command (built with program and args) stdout string is not equal to another.
- Assert a command (built with program and args) stdout string is not equal to another.
- Assert a command (built with program and args) stdout string is not equal to an expression.
- Assert a command (built with program and args) stdout string is not equal to an expression.
- Assert a command (built with program and args) stdout string contains a given containee.
- Assert a command (built with program and args) stdout string contains a given containee.
- Assert a command (built with program and args) stdout string is a match to a regex.
- Assert a command (built with program and args) stdout string is a match to a regex.
- Assert an expression is Ready(_).
- Assert an expression is Ready(_).
- Assert two expressions are Ready(_) and their values are equal.
- Assert two expressions are Ready(_) and their values are equal.
- Assert an expression is Ready(_) and its value is equal to an expression.
- Assert an expression is Ready(_) and its value is equal to an expression.
- Assert two expressions are Ready(_) and their values are not equal.
- Assert two expressions are Ready(_) and their values are not equal.
- Assert an expression is Ready(_) and its value is not equal to an expression.
- Assert an expression is Ready(_) and its value is not equal to an expression.
- assert_
result_ err Deprecated Assert expression is Err(_). - assert_
result_ err_ as_ result Deprecated Assert expression is Err(_). - assert_
result_ ok Deprecated Assert expression is Ok(_). - assert_
result_ ok_ as_ result Deprecated Assert expression is Ok(_). - assert_
result_ ok_ eq Deprecated Assert two expressions are Ok(_) and their values are equal. - assert_
result_ ok_ eq_ as_ result Deprecated Assert two expressions are Ok(_) and their values are equal. - assert_
result_ ok_ ne Deprecated Assert two expressions are Ok(_) and their values are not equal. - assert_
result_ ok_ ne_ as_ result Deprecated Assert two expressions are Ok(_) and their values are not equal. - Assert a set is disjoint with another.
- Assert a set is disjoint with another.
- Assert a set is equal to another.
- Assert a set is equal to another.
- Assert a set is joint with another.
- Assert a set is joint with another.
- Assert a set is not equal to another.
- Assert a set is not equal to another.
- Assert a set is a subset of another.
- Assert a set is a subset of another.
- Assert a set is a superset of another.
- Assert a set is a superset of another.
- Assert expression is Some(_).
- Assert an expression.is_some() is true.
- Assert two expressions are Some(_) and their values are equal.
- Assert a.is_some() and a.unwrap() are equal to another.
- Assert an expression is Some(_) and its value is equal to an expression.
- Assert a.is_some() and a.unwrap() are equal to another.
- Assert two expressions are Some(_) and their values are not equal.
- Assert two expressions are Some(_) and their values are not equal.
- Assert an expression is Some(_) and its value is not equal to an expression.
- Assert a.is_some() and a.unwrap() are equal to another.
- Assert an expression (such as a string) starts with an expression (such as a string).
- Assert an expression (such as a string) starts with an expression (such as a substring).
- Assert every element of the iterator matches a predicate.
- Assert every element of the iterator matches a predicate.
- Assert a number is approximately equal to another number.
- Assert a number is approximately not equal to another number.
- Assert a bag is equal to another.
- Assert a bag is not equal to another.
- Assert a bag is a subbag of another.
- Assert a bag is a superbag of another.
- debug_
assert_ command_ stderr_ contains Deprecated Assert a command stderr string contains a given containee. - Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- debug_
assert_ command_ stderr_ is_ match Deprecated Assert a command stderr string is a match to a regex. - Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string is equal to another.
- Assert a command stderr string is equal to an expression.
- Assert a command stderr string contains a given containee.
- Assert a command stderr string is a match to a regex.
- debug_
assert_ command_ stdout_ contains Deprecated Assert a command stdout string contains a given containee. - Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- debug_
assert_ command_ stdout_ is_ match Deprecated Assert a command stdout string is a match to a regex. - Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string is equal to another.
- Assert a command stdout string is equal to an expression.
- Assert a command stdout string contains a given containee.
- Assert a command stdout string is a match to a regex.
- Assert a container is a match for an expression.
- Assert an expression (such as a string) ends with an expression (such as a string).
- Assert expression is Err(_).
- Assert two expressions are Err(_) and their values are equal.
- Assert an expression is Err(_) and its value is equal to an expression.
- Assert two expressions are Err(_) and their values are not equal.
- Assert an expression is Err(_) and its value is equal to an expression.
- Assert a function output is equal to another function output.
- Assert a function output is equal to an expression.
- Assert a function error is equal to another.
- Assert a function error is equal to an expression.
- Assert a function error is greater than or equal to another.
- Assert a function error is greater than or equal to an expression.
- Assert a function error is greater than another.
- Assert a function error is greater than an expression.
- Assert a function error is less than or equal to another.
- Assert a function error is less than or equal to an expression.
- Assert a function error is less than another.
- Assert a function error is less than an expression.
- Assert a function error is not equal to another.
- Assert a function error is not equal to an expression.
- Assert a function output is greater than or equal to another.
- Assert a function output is greater than or equal to an expression.
- Assert a function output is greater than another.
- Assert a function output is greater than an expression.
- Assert a function output is less than or equal to another.
- Assert a function output is less than or equal to an expression.
- Assert a function output is less than another.
- Assert a function output is less than an expression.
- Assert a function output is not equal to another.
- Assert a function output is not equal to an expression.
- Assert a function Ok(…) is equal to another.
- Assert a function Ok(…) is equal to an expression.
- Assert a function Ok(…) is greater than or equal to another.
- Assert a function Ok(…) is greater than or equal to an expression.
- Assert a function Ok(…) is greater than another.
- Assert a function Ok(…) is greater than an expression.
- Assert a function Ok(…) is less than or equal to another.
- Assert a function Ok(…) is less than or equal to an expression.
- Assert a function Ok(…) is less than another.
- Assert a function Ok(…) is less than an expression.
- Assert a function Ok(…) is not equal to another.
- Assert a function Ok(…) is not equal to an expression.
- Assert a std::fs::read_to_string(path) contains a pattern.
- Assert a std::fs::read_to_string(path) value is equal to another.
- Assert a std::fs::read_to_string(path) value is equal to an expression.
- Assert a std::fs::read_to_string(path) value is greater than or equal to another.
- Assert zzz.
- Assert a std::fs::read_to_string(path) value is greater than another.
- Assert a std::fs::read_to_string(path) value is greater than an expression.
- Assert a std::fs::read_to_string(path) value is less than or equal to another.
- Assert a std::fs::read_to_string(path) value is less than or equal to an expression.
- Assert a std::fs::read_to_string(path) value is less than another.
- Assert a std::fs::read_to_string(path) value is less than an expression.
- Assert a std::fs::read_to_string(path) is a match to a regex.
- Assert a std::fs::read_to_string(path) is not equal to another.
- Assert a std::fs::read_to_string(path) is not equal to an expression.
- Assert an expression is greater than or equal to another expression.
- Assert an expression is greater than another expression.
- Assert a number is within delta of another number.
- Assert a number is within epsilon of another number.
- Assert a infix operator, such as assert_infix!(a == b).
- Assert a std::io::Read read_to_string() contains a pattern.
- Assert a std::io::Read read_to_string() value is equal to another.
- Assert a std::io::Read read_to_string() value is equal to an expression.
- Assert a std::io::Read read_to_string() value is greater than or equal to another.
- Assert zzz.
- Assert a std::io::Read read_to_string() value is greater than another.
- Assert a std::io::Read read_to_string() value is greater than an expression.
- Assert a std::io::Read read_to_string() value is less than or equal to another.
- Assert a std::io::Read read_to_string() value is less than or equal to an expression.
- Assert a std::io::Read read_to_string() value is less than another.
- Assert a std::io::Read read_to_string() value is less than an expression.
- Assert a std::io::Read read_to_string() is a match to a regex.
- Assert a std::io::Read read_to_string() is not equal to another.
- Assert a std::io::Read read_to_string() is not equal to an expression.
- Assert an expression (such as a string or array) is empty.
- Assert a matcher is a match for an expression.
- Assert an iterable is equal to another.
- Assert an iterable is greater than or equal to another.
- Assert an iterable is greater than another.
- Assert an iterable is less than or equal to another.
- Assert an iterable is less than another.
- Assert an iterable is not equal to another.
- Assert an expression is less than or equal to another expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert a value is greater than an expression.
- Assert an expression is less than another expression.
- Assert expression is None.
- Assert an expression (such as a string) does not contain an expression (such as a substring).
- Assert an expression (such as a string or array) is not empty.
- Assert an expression (such as a string) does not end with an expression (such as a string).
- Assert an expression (such as a regex) is not a match for an expression (such as a string).
- Assert an expression (such as a string) does not start with an expression (such as a string).
- Assert expression is Ok(_).
- Assert two expressions are Ok(_) and their values are equal.
- Assert an expression is Ok(_) and its value is equal to an expression.
- Assert two expressions are Ok(_) and their values are not equal.
- Assert an expression is Ok(_) and its value is equal to an expression.
- debug_
assert_ option_ none Deprecated Assert expression is None. - debug_
assert_ option_ some Deprecated Assert expression is Some(_). - debug_
assert_ option_ some_ eq Deprecated Assert two expressions are Some(_) and their values are equal. - debug_
assert_ option_ some_ ne Deprecated Assert two expressions are Some(_) and their values are not equal. - Assert an expression is Pending.
- debug_
assert_ poll_ pending Deprecated Assert an expression is Pending. - debug_
assert_ poll_ ready Deprecated Assert poll.is_ready() is true. - debug_
assert_ poll_ ready_ eq Deprecated Assert two expressions are Ready(_) and their values are equal. - Assert two expressions are Ready(_) and their values are not equal.
- Assert a command (built with program and args) stderr string contains a given containee.
- Assert a command (built with program and args) stderr string is equal to another.
- Assert a command (built with program and args) stderr string is equal to an expression.
- Assert a command (built with program and args) stderr string greater than or equal to another.
- Assert a command (built with program and args) stderr string is greater than or equal to an expression.
- Assert a command (built with program and args) stderr string is equal to another.
- Assert a command (built with program and args) stderr string is greater than an expression.
- Assert a command (built with program and args) stderr string is a match to a regex.
- Assert a command (built with program and args) stderr string is less than or equal to another.
- Assert a command (built with program and args) stderr string is equal to an expression.
- Assert a command (built with program and args) stderr string is less than another.
- Assert a command (built with program and args) stderr string is less than an expression.
- Assert a command (built with program and args) stderr string is not equal to another.
- Assert a command (built with program and args) stderr string is not equal to an expression.
- Assert a command (built with program and args) stderr string contains a given containee.
- Assert a command (built with program and args) stderr string is a match to a regex.
- Assert a command (built with program and args) stdout string contains a given containee.
- Assert a command (built with program and args) stdout string is equal to another.
- Assert a command (built with program and args) stdout string is equal to an expression.
- Assert a command (built with program and args) stdout string is greater than or equal to another.
- Assert a command (built with program and args) stdout string is greater than or equal to an expression.
- Assert a command (built with program and args) stdout string is greater than another.
- Assert a command (built with program and args) stdout string is greater than an expression.
- Assert a command (built with program and args) stdout string is a match to a regex.
- Assert a command (built with program and args) stdout string is less than or equal to another.
- Assert a command (built with program and args) stdout string is less than or equal to an expression.
- Assert a command (built with program and args) stdout string is less than another.
- Assert a command (built with program and args) stdout string is less than an expression.
- Assert a command (built with program and args) stdout string is not equal to another.
- Assert a command (built with program and args) stdout string is not equal to an expression.
- Assert a command (built with program and args) stdout string contains a given containee.
- Assert a command (built with program and args) stdout string is a match to a regex.
- Assert poll.is_ready() is true.
- Assert two expressions are Ready(_) and their values are equal.
- Assert an expression is Ready(_) and its value is equal to an expression.
- Assert two expressions are Ready(_) and their values are not equal.
- Assert an expression is Ready(_) and its value is not equal to an expression.
- debug_
assert_ result_ err Deprecated Assert expression is Err(_). - debug_
assert_ result_ ok Deprecated Assert expression is Ok(_). - debug_
assert_ result_ ok_ eq Deprecated Assert two expressions are Ok(_) and their values are equal. - debug_
assert_ result_ ok_ ne Deprecated Assert two expressions are Ok(_) and their values are not equal. - Assert a set is disjoint with another.
- Assert a set is equal to another.
- Assert a set is joint with another.
- Assert a set is not equal to another.
- Assert a set is a subset of another.
- Assert a set is a superset of another.
- Assert expression is Some(_).
- Assert two expressions are Some(_) and their values are equal.
- Assert an expression is Some(_) and its value is equal to an expression.
- Assert two expressions are Some(_) and their values are not equal.
- Assert an expression is Some(_) and its value is not equal to an expression.
- Assert an expression (such as a string) starts with an expression (such as a string).