Module assert_any

Module assert_any 

Assert for comparing any element of an iterable.

These macros help with comparison of iter parameters, such as a iter of struct and a single struct.

Example

use assertables::*;

let a = [1, 2];
let b = 0;
assert_any_gt_x!(a.iter(), b);

Modules

assert_any
Assert any element of an iterable matches a predicate.
assert_any_eq_x
Assert any element of an iterable is equal to a value.
assert_any_ge_x
Assert any element of an iterable is greater than or equal to a value.
assert_any_gt_x
Assert any element of an iterable is greater than a value.
assert_any_le_x
Assert any element of an iterable is less than or equal to a value.
assert_any_lt_x
Assert any element of an iterable is less than a value.
assert_any_ne_x
Assert any element of an iterable is not equal to a value.