Assert a floating point 32-bit number is not equal to another within f32::EPSILON.
Pseudocode:
a ≠ b
Example
use assertables::*;
let a: f32 = 1.0 / 3.0;
let b: f32 = 0.3333336;
assert_f32_ne!(a, b);Module macros
assert_f32_neassert_f32_ne_as_resultdebug_assert_f32_neAssert a floating point 32-bit number is not equal to another within f32::EPSILON.