Module assert_is_match

Module assert_is_match 

Assert for method is_match(…).

These macros help with any item that implements self.is_match(…).

Example

use assertables::*;
use regex::Regex;

let a = Regex::new(r"lf").expect("regex");
let b = "alfa";
assert_is_match!(a, b);

Modules

assert_is_match
Assert a matcher is a match for an expression.
assert_not_match
Assert an expression (such as a regex) is not a match for an expression (such as a string).