Module assert_option

Assert for Option {Some, None}

Deprecated.

Please rename from assert_option_some* into assert_some*.

Please rename from assert_option_none into assert_none.

Modules

assert_option_none
Assert expression is None.
assert_option_some
Assert expression is Some.
assert_option_some_eq
Assert two expressions are Some and their values are equal.
assert_option_some_ne
Assert two expressions are Some and their values are not equal.