macro_rules! assert_abs_diff_le_as_result { ($a:expr, $b:expr, $delta:expr $(,)?) => { ... }; }
Assert an absolute difference is less than or equal to a delta expression.
Pseudocode:
| a - b | ≤ Δ
-
If true, return
Ok(abs_diff). -
Otherwise, return
Errwith a message and the values of the expressions with their debug representations.
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.