macro_rules! assert_command_stderr_eq_other {
($a_command:expr, $b_command:expr $(,)?) => { ... };
($a_command:expr, $b_command:expr, $($message:tt)+) => { ... };
}Expand description
Assert a command stderr string is equal to another.
-
If true, return
(). -
Otherwise, call
panic!with a message and the values of the expressions with their debug representations.
Examples
use std::process::Command;
// Return Ok
let mut a = Command::new("printf");
let mut b = Command::new("printf");
assert_command_stderr_eq_other!(a, b);
//-> ()
// Panic with error message
let result = panic::catch_unwind(|| {
let mut a = Command::new("printf");
let mut b = Command::new("printf");
b.arg("-v");
assert_command_stderr_eq_other!(a, b);
//-> panic!("…")
let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
let expect = concat!(
"assertion failed: `assert_command_stderr_eq_other!(left_command, right_command)`\n",
" left_command label: `a`,\n",
" left_command debug: `\"printf\"`,\n",
" right_command label: `b`,\n",
" right_command debug: `\"printf\" \"-v\"`,\n",
" left: `\"usage: printf format [arguments ...]\\n\"`,\n",
" right: `\"printf: illegal option -- v\\nusage: printf format [arguments ...]\\n\"`"
);
assert_eq!(actual, expect);
// Panic with error message
let result = panic::catch_unwind(|| {
let mut a = Command::new("printf");
let mut b = Command::new("printf");
b.arg("-v");
assert_command_stderr_eq_other!(a, b, "message");
//-> panic!("…")
});
assert!(result.is_err());
let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
let expect = "message";
assert_eq!(actual, expect);