macro_rules! assert_command_stderr_ne_x_as_result { ($a_command:expr, $b_expr:expr $(,)?) => { ... }; }
Assert a command stderr string is not equal to an expression.
Pseudocode:
(command ⇒ stderr) = (expr into string)
-
If true, return Result
Ok(stderr). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.