macro_rules! assert_command_stderr_string_contains_as_result { ($command:expr, $containee:expr $(,)?) => { ... }; }
Assert a command stderr string contains a given containee.
Pseudocode:
(command ⇒ stderr ⇒ string) contains (expr into string)
-
If true, return Result
Ok(command ⇒ stderr ⇒ string). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_command_stderr_string_contains,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.