macro_rules! assert_command_stdout_gt_as_result { ($a_command:expr, $b_command:expr $(,)?) => { ... }; }
Assert a command stdout string is equal to another.
Pseudocode:
(command1 ⇒ stdout) = (command2 ⇒ stdout)
-
If true, return Result
Ok(stdout). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.