assertables

Macro assert_count_ne_as_result

macro_rules! assert_count_ne_as_result {
    ($a:expr, $b:expr $(,)?) => { ... };
}
Assert a count is equal to another count.

Pseudocode:
a.count() ≠ b.count()

  • If true, return Result Ok((a.count(), b)).

  • Otherwise, return Result Err(message).

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros