assertables

Macro assert_ends_with_as_result

macro_rules! assert_ends_with_as_result {
    ($sequence:expr, $subsequence:expr $(,)?) => { ... };
}
Assert an expression (such as a string) ends with an expression (such as a substring).

Pseudocode:
a.ends_with(b)

  • If true, return Result Ok(()).

  • Otherwise, return Result Err(message).

This macro provides the same statements as assert_ends_with, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros