macro_rules! assert_eq_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
Assert an expression is equal to another expression.
Pseudocode:
a = b
-
If true, return Result
Ok(()). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.