assertables

Macro assert_err_ne2_as_result

source
macro_rules! assert_err_ne2_as_result {
    ($a:expr, $b:expr $(,)?) => { ... };
}
Assert two expressions are Err and their values are not equal.

Pseudocode:
(a ⇒ Err(a1) ⇒ a1) ≠ (b ⇒ Err(b1) ⇒ b1)

  • If true, return Result Ok((a1, b1)).

  • Otherwise, return Result Err(message).

This macro provides the same statements as assert_err_ne2, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros