assertables

Macro assert_err_ne_as_result

source
macro_rules! assert_err_ne_as_result {
    ($a:expr, $b:expr $(,)?) => { ... };
}
Assert two expressions are Err(_) and their values are not equal.

Pseudocode:
(a ⇒ Err(a̅) ⇒ a̅) ≠ (b ⇒ Err(b̅) ⇒ b̅)

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_err_ne, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros