macro_rules! assert_f_le {
    ($function:path, $left:expr, $right:expr $(,)?) => { ... };
    ($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... };
}
Assert a function output is less than or equal to another.

  • When true, return ().

  • Otherwise, call panic! with a message and the values of the expressions with their debug representations.

Examples

assert_f_le!(i32::abs, 1 as i32, -2 as i32);
//-> ()

assert_f_le!(i32::abs, -2 as i32, 1 as i32);
//-> panic!("…")
// assertion failed: `assert_f_le!(function, left, right)`
//    left input: `-2`,
//   right input: `1`,
//   left output: `2`,
//  right output: `1`

This macro has a second form where a custom message can be provided.