Macro assertables::assert_f_ok_eq
source · [−]macro_rules! assert_f_ok_eq {
($function:path, $left:expr, $right:expr $(,)?) => { ... };
($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... };
}Expand description
Assert a function ok() is equal to another.
-
When true, return
(). -
Otherwise, call
panic!with a message and the values of the expressions with their debug representations.
Examples
use std::str::FromStr;
assert_f_ok_eq!(i32::from_str, "1", "1");
//-> ()
assert_f_ok_eq!(i32::from_str, "1", "2");
//-> panic!("…")
// assertion failed: `assert_f_ok_eq!(function, left, right)`
// left input: `\"1\"`,
// right input: `\"2\"`,
// left output: `1`,
// right output: `2`This macro has a second form where a custom message can be provided.