Macro assertables::assert_f_ok_gt
source · [−]macro_rules! assert_f_ok_gt {
($function:path, $left:expr, $right:expr $(,)?) => { ... };
($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... };
}Expand description
Assert a function ok() is greater than another.
-
When true, return
(). -
Otherwise, call
panic!with a message and the values of the expressions with their debug representations.
Examples
fn example_digit_to_string(i: isize) -> Result<String, String> {
match i {
0..=9 => Ok(format!("{}", i)),
_ => Err(format!("{:?} is out of range", i)),
}
}
assert_f_ok_gt!(example_digit_to_string, 2, 1);
//-> ()
assert_f_ok_gt!(example_digit_to_string, 1, 2);
//-> panic!("…")
// assertion failed: `assert_f_ok_gt!(function, left, right)`
// function: `\"example_digit_to_string\"`,
// left input: `1`,
// right input: `2`,
// left output: `\"1\"`,
// right output: `\"2\"`This macro has a second form where a custom message can be provided.