Macro assertables::assert_fn_err_string_eq [−][src]
macro_rules! assert_fn_err_string_eq { ($function:path, $left:expr, $right:expr $(,)?) => { ... }; ($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... }; }
Assert one function ok() is equal to another function ok().
-
When true, return
(). -
Otherwise, call
panic!with a message and the values of the expressions with their debug representations.
Example
fn f(i: i32) -> Result<bool, String> { Err(format!("{:?}", i)) } assert_fn_err_string_eq!(f, 1, 1); //-> ()
// fn f(i: i32) -> Result<bool, String> { Err(format!("{:?}", i)) } // assert_fn_err_string_eq!(f, 1, "b); //-> panic!("assertion failed: `assert_fn_err_string_eq(fn, left, right)`\n left input: `1`\n right input: `2`\n left output: `\"1\"`\n right output: `\"2\"`")
This macro has a second form where a custom message can be provided.