macro_rules! assert_fn_gt_x_as_result { ($a_function:path, $a_param:expr, $b_expr:expr $(,)?) => { ... }; ($a_function:path, $b_expr:expr $(,)?) => { ... }; }
Assert a function output is greater than an expression.
Pseudocode:
function(a) > b
-
If true, return Result
Ok(a). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.