Macro assertables::assert_fn_le_expr_as_result

source ·
macro_rules! assert_fn_le_expr_as_result {
    ($a_function:path, $a_param:expr, $b_expr:expr $(,)?) => { ... };
    ($a_function:path, $b_expr:expr $(,)?) => { ... };
}
Assert a function output is less than or equal to an expression.

  • If true, return Ok(()).

  • Otherwise, return Err with a message and the values of the expressions with their debug representations.

Examples

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros