macro_rules! assert_fn_ne {
    ($function:path, $a_input:expr, $b_expr:expr $(,)?) => { ... };
    ($function:path, $a_input:expr, $b_expr:expr, $($arg:tt)+) => { ... };
}
Assert a function output is not equal to another.

  • If true, return ().

  • Otherwise, call panic! with a message and the values of the expressions with their debug representations.

Examples

let a: i32 = 1;
let b: i32 = -2;
assert_fn_ne!(i32::abs, a, b);
//-> ()

let result = panic::catch_unwind(|| {
let a: i32 = -1;
let b: i32 = 1;
assert_fn_ne!(i32::abs, a, b);
//-> panic!
});
let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
let expect = concat!(
    "assertion failed: `assert_fn_ne!(left_function, left_input, right_expr)`\n",
    " left_function label: `i32::abs`,\n",
    "    left_input label: `a`,\n",
    "    left_input debug: `-1`,\n",
    "    right_expr label: `b`,\n",
    "    right_expr debug: `1`,\n",
    "                left: `1`,\n",
    "               right: `1`"
);
assert_eq!(actual, expect);