assertables

Macro assert_fn_ne2_as_result

source
macro_rules! assert_fn_ne2_as_result {
    ($a_function:path, $a_param:expr, $b_function:path, $b_param:expr $(,)?) => { ... };
    ($a_function:path, $b_function:path) => { ... };
}
Assert a function output is not equal to another.

Pseudocode:
a_function(a) ≠ b_function(b)

  • If true, return Result Ok(a, b).

  • Otherwise, return Result Err(message).

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros