macro_rules! assert_fn_ok_le_expr_as_result { ($a_function:path, $a_param:expr, $b_expr:expr $(,)?) => { ... }; ($a_function:path, $b_expr:expr $(,)?) => { ... }; }
Assert a function Ok(…) is less than or equal to an expression.
Pseudocode:
(function1(param1) ⇒ Ok(a) ⇒ a) ≤ expr
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.