macro_rules! assert_fn_ok_lt_expr_as_result { ($a_function:path, $a_param:expr, $b_expr:expr) => { ... }; ($a_function:path, $b_expr:expr) => { ... }; }
Assert a function ok() is less than an expression.
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
Examples
This macro provides the same statements as [assert_],
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.
Related
- [
assert_fn_ok_lt_expr] - [
assert_fn_ok_lt_expr_as_result] - [
debug_assert_fn_ok_lt_expr]