macro_rules! assert_fs_read_to_string_lt_as_result { ($a_path:expr, $b_path:expr $(,)?) => { ... }; }
Assert a std::fs::read_to_string(path) value is less than another.
Pseudocode:
std::fs::read_to_string(path1) < std::fs::read_to_string(path2)
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_fs_read_to_string_lt,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.