macro_rules! assert_fs_read_to_string_lt_expr_as_result { ($a_path:expr, $b_expr:expr $(,)?) => { ... }; }
Assert a std::fs::read_to_string() value is less than an expression.
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_fs_read_to_string_lt_expr,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.