macro_rules! assert_io_ne {
    ($left:expr, $right:expr $(,)?) => { ... };
    ($left:expr, $right:expr, $($arg:tt)+) => { ... };
}
Assert a value is equal to another.

  • When true, return ().

  • Otherwise, call panic! with a message and the values of the expressions with their debug representations.

Examples

assert_io_ne!(1, 2);
//-> ()

assert_io_ne!(1, 1);
//-> panic!("…")
// assertion failed: `assert_io_ne!(left, right)`
//   left: `1`,
//  right: `1`

This macro has a second form where a custom message can be provided.