macro_rules! assert_io_read_to_string_gt2_as_result { ($a_reader:expr, $b_reader:expr $(,)?) => { ... }; }
Assert a ::std::io::Read read_to_string() value is greater than another.
Pseudocode:
(a_reader.read_to_string(a_string) ⇒ a_string) > (b_reader.read_to_string(b_string) ⇒ b_string)
-
If true, return Result
Ok((a_string, b_string)). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.