macro_rules! assert_io_read_to_string_le_as_result { ($a_reader:expr, $b_reader:expr $(,)?) => { ... }; }
Assert a std::io::Read read_to_string() value is less than or equal to another.
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as [assert_],
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.
Related
- [
assert_io_read_to_string_le] - [
assert_io_read_to_string_le_as_result] - [
debug_assert_io_read_to_string_le]