macro_rules! assert_io_read_to_string_lt_as_result {
    ($a_reader:expr, $b_reader:expr $(,)?) => { ... };
}
Assert a std::io::Read read_to_string() value is less than another.

Pseudocode:
(reader1.read_to_string(a) ⇒ a) < (reader2.read_to_string(b) ⇒ b)

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros