assertables

Macro assert_iter_gt_as_result

source
macro_rules! assert_iter_gt_as_result {
    ($a_collection:expr, $b_collection:expr $(,)?) => { ... };
}
Assert an iterable is greater than another.

Pseudocode:
(collection1 into iter) > (collection2 into iter)

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

This implementation uses std::collections::BTreeSet to count items and sort them.

Module macros