assertables

Macro assert_len_ge_x_as_result

macro_rules! assert_len_ge_x_as_result {
    ($a:expr, $b:expr $(,)?) => { ... };
}
Assert a length is greater than or equal to an expression.

Pseudocode:
a.len() ≥ b

  • If true, return Result Ok((a.len(), b)).

  • Otherwise, return Result Err(message).

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros