macro_rules! assert_len_gt_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
Assert a length is greater than another length.
Pseudocode:
a.len() > b.len()
-
If true, return Result
Ok((a.len(), b.len())). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.