Macro assertables::assert_ne_as_result
source · macro_rules! assert_ne_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
Assert an expression is not equal to an expression.
-
If true, return Result
Ok(()). -
When false, return
Errwith a message and the values of the expressions with their debug representations.
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.