macro_rules! assert_not_ends_with_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
Assert an expression (such as a string) does not end with an expression (such as a substring).
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_not_ends_with,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.