assertables

Macro assert_ok_as_result

source
macro_rules! assert_ok_as_result {
    ($a:expr $(,)?) => { ... };
}
Assert expression is Ok(_).

Pseudocode:
a is Ok(_)

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_ok, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros