macro_rules! assert_ok_eq_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
Assert an expression is Ok and its value is equal to an expression.
Pseudocode:
(a ⇒ Ok(a1) ⇒ a1) = b
-
If true, return Result
Ok(a1). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_ok_eq,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.