macro_rules! assert_option_some_eq_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
๐Deprecated: Please rename from
assert_option_some_eq_as_result to assert_some_eq_as_result because more developers prefer the shorter name.Expand description
Assert a.is_some() and a.unwrap() are equal to another.
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_option_some_eq,
except this macro returns a Option, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.