Macro assertables::assert_poll_pending_as_result

source ·
macro_rules! assert_poll_pending_as_result {
    ($poll:expr $(,)?) => { ... };
}
Assert an expression.is_pending() is true.

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_poll_pending, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros