assertables

Macro assert_poll_ready_eq_as_result

source
macro_rules! assert_poll_ready_eq_as_result {
    ($a:expr, $b:expr $(,)?) => { ... };
}
๐Ÿ‘ŽDeprecated: Please rename from assert_poll_ready_eq_as_result to assert_ready_eq_as_result because more developers prefer the shorter name.
Assert two expressions are Ready(_) and their values are equal.

  • If true, return Result Some(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_poll_ready_eq, except this macro returns a Option, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros