macro_rules! assert_poll_ready_ne_as_result { ($a:expr, $b:expr $(,)?) => { ... }; }
๐Deprecated: Please rename from
assert_poll_ready_ne_as_result to assert_ready_ne_as_result because more developers prefer the shorter name.Expand description
Assert two expressions are Ready(_) and their values are not equal.
-
If true, return Result
Some(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_poll_ready_ne,
except this macro returns a Option, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.