macro_rules! assert_process_status_code_value_ge_x_as_result { ($a_process:expr, $b:expr $(,)?) => { ... }; }
Assert a process status code value is greater than or equal to an expression.
Pseudocode:
a.len() ≥ b
-
If true, return Result
Ok(a ⇒ status ⇒ code ⇒ value). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.