macro_rules! assert_program_args_stderr_ge_as_result { ($a_program:expr, $a_args:expr, $b_program:expr, $b_args:expr $(,)?) => { ... }; }
Assert a command (built with program and args) stderr string is greater than or equal to another.
Pseudocode:
(program1 + args1 ⇒ command ⇒ stderr) ≥ (program2 + args2 ⇒ command ⇒ stderr)
-
If true, return Result
Ok(stderr). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.