macro_rules! assert_program_args_stdout_is_match_as_result { ($a_program:expr, $a_args:expr, $matcher:expr $(,)?) => { ... }; }
๐Deprecated: Please rename from
assert_program_args_stdout_is_match_as_result to assert_program_args_stdout_string_is_match_as_result because this macro does the comparison via a Rust UTF-8 String.Expand description
Assert a command (built with program and args) stdout string is a match to a regex.
Pseudocode:
(program1 + args1 โ command โ stdout โ string) is match (expr into string)
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.