macro_rules! assert_ready_as_result { ($a:expr $(,)?) => { ... }; }
Assert an expression is Ready.
Pseudocode:
a is Ready(a1)
-
If true, return Result
Ok(a1). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_ready,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.