assertables

Macro assert_result_err_as_result

source
macro_rules! assert_result_err_as_result {
    ($a:expr $(,)?) => { ... };
}
๐Ÿ‘ŽDeprecated: Please rename from assert_result_err_as_result to assert_err_as_result because more developers prefer the shorter name.
Assert expression is Err(_).

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_result_err, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros