Macro assertables::assert_result_ok_eq_as_result

source ·
macro_rules! assert_result_ok_eq_as_result {
    ($a:expr, $b:expr $(,)?) => { ... };
}
👎Deprecated: Please rename from assert_result_ok_eq_as_result to assert_ok_eq_as_result because more developers prefer the shorter name.
Assert two expressions are Ok(_) and their values are equal.

  • If true, return Result Ok(()).

  • Otherwise, return Result Err with a diagnostic message.

This macro provides the same statements as assert_result_ok_eq, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros