macro_rules! assert_set_joint_as_result { ($a_collection:expr, $b_collection:expr $(,)?) => { ... }; }
Assert a set is joint with another.
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as assert_,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.