macro_rules! assert_starts_with_as_result { ($whole:expr, $part:expr $(,)?) => { ... }; }
Assert an expression (such as a string) starts with an expression (such as a substring).
Pseudocode:
a.starts_with(b)
-
If true, return Result
Ok(()). -
Otherwise, return Result
Err(message).
This macro provides the same statements as assert_starts_with,
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.