assertables

Macro assert_success_false_as_result

macro_rules! assert_success_false_as_result {
    ($a:expr $(,)?) => { ... };
}
Assert a failure method is true.

Pseudocode:
a.success() = false

  • If true, return Result Ok(true).

  • Otherwise, return Result Err(message).

This macro provides the same statements as assert_, except this macro returns a Result, rather than doing a panic.

This macro is useful for runtime checks, such as checking parameters, or sanitizing inputs, or handling different results in different ways.

Module macros