macro_rules! assertable_command_stdout_eq_str {
    ($command:expr, $expect:expr $(,)?) => { ... };
    ($command:expr, $expect:expr, $($arg:tt)+) => { ... };
}
Assert a command stdout string is equal to a target string.

  • When true, return Ok(()).

  • Otherwise, return Err with a message and the values of the expressions with their debug representations.

Examples

use std::process::Command;
 
let mut a = Command::new("printf");
a.args(["%s", "hello"]);
let x = assertable_command_stdout_eq_str!(a, "hello");
//-> Ok(())
assert_eq!(x.unwrap(), ());

let mut a = Command::new("printf");
a.args(["%s", "hello"]);
let x = assertable_command_stdout_eq_str!(a, "world");
//-> Err!("…")
// assertable failed: `assertable_command_stdout_eq_str!(command, expect)`
//  command program: `\"printf\"`,
//  stdout: `\"hello\"`,
//  expect: `\"world\"`

This macro has a second form where a custom message can be provided.