Macro assertables::assertable_f_ge
source · [−]macro_rules! assertable_f_ge {
($function:path, $left:expr, $right:expr $(,)?) => { ... };
($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... };
}Expand description
Assert one function output is not equal to another function output.
-
When true, return
Ok(()). -
Otherwise, return
Errwith a message and the values of the expressions with their debug representations.
Examples
let x = assertable_f_ge!(i32::abs, -2 as i32, 1 as i32);
//-> Ok(())
assert_eq!(x.unwrap(), ());
let x = assertable_f_ge!(i32::abs, 1 as i32, -2 as i32);
//-> Err("…")
// assertable failed: `assertable_f_ge!(function, left, right)`
// left input: `1`,
// right input: `-2`,
// left output: `1`,
// right output: `2`
assert_eq!(x.unwrap_err(), "assertable failed: `assertable_f_ge!(function, left, right)`\n left input: `1`,\n right input: `-2`,\n left output: `1`,\n right output: `2`".to_string());This macro has a second form where a custom message can be provided.