Macro assertables::assertable_f_ok_eq
source · [−]macro_rules! assertable_f_ok_eq {
($function:path, $left:expr, $right:expr $(,)?) => { ... };
($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... };
}Expand description
Assert one function ok() is equal to another function ok().
-
When true, return
Ok(()). -
Otherwise, return
Errwith a message and the values of the expressions with their debug representations.
Examples
fn example_digit_to_string(i: isize) -> Result<String, String> {
match i {
0..=9 => Ok(format!("{}", i)),
_ => Err(format!("{:?} is out of range", i)),
}
}
let x = assertable_f_ok_eq!(example_digit_to_string, 1, 1);
//-> Ok(())
assert_eq!(x.unwrap(), ());
let x = assertable_f_ok_eq!(example_digit_to_string, 1, 2);
//-> Err("…")
// assertable failed: `assertable_f_ok_eq!(function, left, right)`
// function: `\"example_digit_to_string\"`,
// left input: `1`,
// right input: `2`,
// left output: `\"1\"`,
// right output: `\"2\"`
assert_eq!(x.unwrap_err(), "assertable failed: `assertable_f_ok_eq!(function, left, right)`\n function: `\"example_digit_to_string\"`,\n left input: `1`,\n right input: `2`,\n left output: `\"1\"`,\n right output: `\"2\"`".to_string());This macro has a second form where a custom message can be provided.