Macro assertables::assume_fn_ok_gt[][src]

macro_rules! assume_fn_ok_gt {
    ($function:path, $left:expr, $right:expr $(,)?) => { ... };
    ($function:path, $left:expr, $right:expr, $($arg:tt)+) => { ... };
}
Assume one function ok() is greater than another function ok().

  • When true, return Ok(true).

  • Otherwise, return Err with a message and the values of the expressions with their debug representations.

Example

assume_fn_ok_gt!(i32::from_str, "2", "1");
//-> Ok(true)
assume_fn_ok_gt!(i32::from_str, "1", "2");
//-> Err("assumption failed: `assume_fn_ok_gt(left, right)`\n  left input: `\"1\"`\n right input: `\"2\"`\n  left output: `1`\n right output: `2`")

This macro has a second form where a custom message can be provided.