Macro assertables::assume_io_le [−][src]
macro_rules! assume_io_le { ($left:expr, $right:expr $(,)?) => { ... }; ($left:expr, $right:expr, $($arg:tt)+) => { ... }; }
Assume one value is less than or equal to another value.
-
When true, return
Ok(true). -
When false, return
Ok(false). -
Otherwise, return
Errwith a message and the values of the expressions with their debug representations.
Examples
let x = assume_io_le!(1, 2); //-> Ok(true)
let x = assume_io_le!(2, 1); //-> Err( // std::io::Error::new( // std::io::ErrorKind::InvalidInput, // "assumption failed: `assume_io_le(left, right)`\n left: `2`\n right: `1`")] // ) // )
This macro has a second form where a custom message can be provided.