Macro assertables::assure_set_ne [−][src]
Assure two sets are not equal.
-
When true, return
Ok(true). -
When false, return
Ok(false). -
Otherwise, return
Errwith a message and the values of the expressions with their debug representations.
Example
let x = assure_set_ne!([1, 2], [3, 4]); //-> Ok(true)
let x = assure_set_ne!([1, 2], [1, 2]); //-> Ok(false)
This macro has a second form where a custom message can be provided.
This implementation uses [HashSet] to count items.