macro_rules! assert_command_stderr_eq_other {
($a_command:expr, $b_command:expr $(,)?) => { ... };
($a_command:expr, $b_command:expr, $($arg:tt)+) => { ... };
}Expand description
Assert a command stderr string is equal to another.
-
When true, return
(). -
Otherwise, call
panic!with a message and the values of the expressions with their debug representations.
Examples
use std::process::Command;
let mut a = Command::new("printf");
let mut b = Command::new("printf");
assert_command_stderr_eq_other!(a, b);
//-> ()
let mut a = Command::new("printf");
let mut b = Command::new("printf");
b.arg("-v");
assert_command_stderr_eq_other!(a, b);
//-> panic!("…")
let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
let expect = concat!(
"assertion failed: `assert_command_stderr_eq_other!(left_command, right_command)`\n",
" left command name: `a`,\n",
" right command name: `b`,\n",
" left command: `\"printf\"`,\n",
" right command: `\"printf\"`,\n",
" left: `\"usage: printf format [arguments ...]\\n\"`,\n",
" right: `\"printf: illegal option -- v\\nusage: printf format [arguments ...]\\n\"`"
);
assert_eq!(actual, expect);This macro has a second form where a custom message can be provided.