macro_rules! assert_program_args_stdout_is_match_as_result { ($a_program:expr, $a_args:expr, $b_matcher:expr $(,)?) => { ... }; }
Assert a command (built with program and args) stdout string is a match to a regex.
-
If true, return Result
Ok(()). -
Otherwise, return Result
Errwith a diagnostic message.
This macro provides the same statements as [assert_],
except this macro returns a Result, rather than doing a panic.
This macro is useful for runtime checks, such as checking parameters, or santizing inputs, or handling different results in different ways.